@@ -4,8 +4,8 @@
 
  Copyright (c) 1998 by Kevin Atkinson, (c) 1999-2001 by MySQL AB, and
  (c) 2004-2007 by Educational Technology Resources, Inc.  Others may
- also hold copyrights on code in this file.  See the CREDITS file in
- the top directory of the distribution for details.
+ also hold copyrights on code in this file.  See the CREDITS.txt file
+ in the top directory of the distribution for details.
 
  This file is part of MySQL++.
 
@@ -38,11 +38,6 @@
 using namespace std;
 
 
-// Access the flag that's set when running under the dtest framework, so
-// we modify our output to be testable.
-extern bool dtest_mode;
-
-
 // Insert a bar into the stream with the given query string centered
 static void
 separator(ostream& os, string qstr)
@@ -73,16 +68,16 @@ show_mysql_version(mysqlpp::Connection& con)
 static void
 show_databases(mysqlpp::Connection& con)
 {
-    mysqlpp::Query query = con.query("show databases");
+	mysqlpp::Query query = con.query("show databases");
 	separator(cout, query.str());
-    mysqlpp::StoreQueryResult res = query.store();
+	mysqlpp::StoreQueryResult res = query.store();
 
-    cout << "Databases found: " << res.size();
-    cout.setf(ios::left);
-    mysqlpp::StoreQueryResult::iterator rit;
-    for (rit = res.begin(); rit != res.end(); ++rit) {
-        cout << "\n\t" << (*rit)[0];
-    }
+	cout << "Databases found: " << res.size();
+	cout.setf(ios::left);
+	mysqlpp::StoreQueryResult::iterator rit;
+	for (rit = res.begin(); rit != res.end(); ++rit) {
+		cout << "\n\t" << (*rit)[0];
+	}
 }
 
 
@@ -145,14 +140,14 @@ show_table_info(mysqlpp::Connection& con, const vector<string>& tables)
 static void
 show_tables(mysqlpp::Connection& con)
 {
-    mysqlpp::Query query = con.query("show tables");
+	mysqlpp::Query query = con.query("show tables");
 	separator(cout, query.str());
 	mysqlpp::StoreQueryResult res = query.store();
 
 	cout << "Tables found: " << res.size();
 	cout.setf(ios::left);
 	vector<string> tables;
-    mysqlpp::StoreQueryResult::iterator rit;
+	mysqlpp::StoreQueryResult::iterator rit;
 	for (rit = res.begin(); rit != res.end(); ++rit) {
 		string tbl((*rit)[0]);
 		cout << "\n\t" << tbl;
@@ -168,22 +163,16 @@ int
 main(int argc, char* argv[])
 {
 	// Get database access parameters from command line
-    const char* db = 0, *server = 0, *user = 0, *pass = "";
+	const char* db = 0, *server = 0, *user = 0, *pass = "";
 	if (!parse_command_line(argc, argv, &db, &server, &user, &pass)) {
 		return 1;
 	}
 
 	try {
-		// Establish the connection to the database server.
+		// Connect to server, then dump a bunch of stuff we find on it
 		mysqlpp::Connection con(db, server, user, pass);
-
-		// Show system-specific tests info when run by hand only.
-		if (!dtest_mode) {
-			show_mysql_version(con);
-			show_databases(con);
-		}
-
-		// Show database info that's platform-independent
+		show_mysql_version(con);
+		show_databases(con);
 		show_tables(con);
 	}
 	catch (const mysqlpp::BadQuery& er) {
