@@ -3,8 +3,8 @@
 
  Copyright (c) 1998 by Kevin Atkinson, (c) 1999-2001 by MySQL AB, and
  (c) 2004-2008 by Educational Technology Resources, Inc.  Others may
- also hold copyrights on code in this file.  See the CREDITS file in
- the top directory of the distribution for details.
+ also hold copyrights on code in this file.  See the CREDITS.txt file
+ in the top directory of the distribution for details.
 
  This file is part of MySQL++.
 
@@ -353,21 +353,21 @@ Connection::shutdown()
 
 
 bool
-Connection::thread_aware() const
+Connection::thread_aware()
 {
-	return driver_->thread_aware();
+	return DBDriver::thread_aware();
 }
 
 
 void
 Connection::thread_end()
 {
-	driver_->thread_end();
+	DBDriver::thread_end();
 }
 
 
-unsigned long 
-Connection::thread_id() 
+unsigned long
+Connection::thread_id()
 {
 	return driver_->thread_id();
 }
@@ -376,7 +376,7 @@ Connection::thread_id()
 bool
 Connection::thread_start()
 {
-	return driver_->thread_start();
+	return DBDriver::thread_start();
 }
 
 } // end namespace mysqlpp
